@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Itself ;
-$Config::Model::Itself::VERSION = '1.244';
+$Config::Model::Itself::VERSION = '1.245';
 use Mouse ;
 use Config::Model 2.064;
 use 5.010;
@@ -560,14 +560,14 @@ Config::Model::Itself - Model editor for Config::Model
 
 =head1 VERSION
 
-version 1.244
+version 1.245
 
 =head1 SYNOPSIS
 
  my $meta_model = Config::Model -> new ( ) ;
 
  # load Config::Model model
- my $meta_inst = $model->instance (
+ my $meta_inst = $meta_model->instance (
     root_class_name => 'Itself::Model' ,
     instance_name   => 'meta_model' ,
  );
@@ -692,7 +692,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dominique Dumont.
+This software is Copyright (c) 2015 by Dominique Dumont.
 
 This is free software, licensed under:
 
