@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -26,7 +26,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
 package Config::Model::Itself::TkEditUI ;
-$Config::Model::Itself::TkEditUI::VERSION = '1.244';
+$Config::Model::Itself::TkEditUI::VERSION = '1.245';
 use strict;
 use warnings ;
 use Carp ;
@@ -68,7 +68,30 @@ sub Populate {
 sub test_model {
     my $cw = shift ;
 
-    $cw->save_if_yes("save model data ?") ;
+    if ( $cw->{root}->instance->needs_save ) {
+        my $answer = $cw->Dialog(
+            -title          => "save model before test",
+            -text           => "Save model ?",
+            -buttons        => [ qw/yes no cancel/, 'show changes' ],
+            -default_button => 'yes',
+        )->Show;
+
+        if ( $answer eq 'yes' ) {
+            $cw->save( sub {$cw->_launch_test;});
+        }
+        elsif ( $answer eq 'no' ) {
+            $cw->_launch_test;
+        }
+        elsif ( $answer =~ /show/ ) {
+            $cw->show_changes( sub { $cw->test_model } );
+        }
+    }
+    else {
+        $cw->_launch_test;
+    }
+}
+sub _launch_test {
+    my $cw = shift ;
 
     my $testw =  $cw -> {test_widget} ;
     $testw->destroy if defined $testw and Tk::Exists($testw);
